@@ -375,6 +375,16 @@ class AlchemyCacheStorage(object):
         """
         return self._hash_algorithms[self.fingerprint_hash_algorithm_name]
 
+    @property
+    def use_content_extraction(self) -> bool:
+        """
+        Whether or not the plain text content of the html is going to be
+        extracted from the html.
+
+        :return: ``True`` if the content will be extracted.
+        """
+        return get_setting('SCRACHY_USE_CONTENT_EXTRACTION', self._settings)
+
     @property
     def use_simhash(self) -> bool:
         """
@@ -970,6 +980,20 @@ class AlchemyCacheStorage(object):
                 f"The supported option are: {valid_response_methods}"
             )
 
+        if self.use_simhash and not self.use_content_extraction:
+            log.warning(
+                "SCRACHY_USE_SIMHASH is True, but SCRACHY_USE_CONTENT_EXTRACTION is False. "
+                "Computing the simhash is dependent on extracting the content of the page. "
+                "No simhash will be computed or stored in the database."
+            )
+
+        if self.store_text and not self.use_content_extraction:
+            log.warning(
+                "SCRACHY_STORE_TEXT is True, but SCRACHY_USE_CONTENT_EXTRACTION is False. "
+                "Storing the extracted content text is dependent on using content extraction. "
+                "No content text will be stored in the cache."
+            )
+
     def _validate_hash_algorithm(self, hash_name: str):
         # The hash algorithms are only populated once the spider is opened.
         # If you want to call this before opening the spider, fall back
@@ -1209,11 +1233,24 @@ class AlchemyCacheStorage(object):
             fingerprint: bytes
     ):
         # Make the medatadata item
-        response_body_text = self.extract_text(
-            response.text,
-            self.content_extraction_method_name,
-            self.content_extraction_parser_name
-        )
+
+        # Extracting the text is optional
+        if self.use_content_extraction:
+            response_body_text = self.extract_text(
+                response.text,
+                self.content_extraction_method_name,
+                self.content_extraction_parser_name
+            )
+
+            text_number_of_bytes = len(response_body_text)
+
+            # Simhash is contingent on extracting the text.
+            simhash_value = self.compute_simhash(response_body_text)
+
+        else:
+            response_body_text = None
+            text_number_of_bytes = None
+            simhash_value = None
 
         cached_metadata = CachedResponseMeta(
             region=self.region,
@@ -1224,11 +1261,12 @@ class AlchemyCacheStorage(object):
             content_extraction_method=self.content_extraction_method,
             content_extraction_parser=self.content_extraction_parser,
             response_body_html_number_of_bytes=len(to_bytes(response.text)),
-            response_body_text_number_of_bytes=len(to_bytes(response_body_text)),
+            response_body_text_number_of_bytes=text_number_of_bytes,
             simhash_hash_algorithm=self.simhash_hash_algorithm,
-            response_body_text_simhash=self.compute_simhash(response_body_text)
+            response_body_text_simhash=simhash_value
         )
 
+        # Storing the text is also optional
         if self.store_text:
             cached_metadata.response_body_text = response_body_text
 
