@@ -262,11 +262,13 @@ class TestAlchemyCacheStorage(unittest.TestCase):
     def test_store_response_no_duplicates(self):
         filename1, url1 = 'test_page_1.html', 'http://www.example1.com/'
         filename2, url2 = 'test_page_2.html', 'http://www.example2.com/'
+        filename3, url3 = 'test_page_2.html', 'http://www.example3.com/'
 
         # We'll store three request/responses in the cache
         request1, response1 = make_response_from_file(filename1, url1)
         request2, response2 = make_response_from_file(filename2, url2)
         request3, response3 = make_response_from_file(filename2, url2, '{param=value}')
+        request4, response4 = make_response_from_file(filename3, url3, '{param=value}')
 
         settings = make_settings(self.region_name)
 
@@ -296,10 +298,11 @@ class TestAlchemyCacheStorage(unittest.TestCase):
             self.assertEqual(item.response_body_html, response1.text)
             self.assertEqual(item.response_body_text, None)
             self.assertEqual(item.response_body_html_number_of_bytes, 625)
-            self.assertEqual(item.response_body_text_number_of_bytes, 257)
+            self.assertIsNone(item.response_body_text_number_of_bytes)
             self.assertEqual(item.response_body_text_simhash, None)
 
-            # Test store text
+            # Test store text if extract content is True
+            settings.set('SCRACHY_USE_CONTENT_EXTRACTION', True)
             settings.set('SCRACHY_STORE_TEXT', True)
             storage = AlchemyCacheStorage(settings)
             storage.open_spider(None)
@@ -320,6 +323,25 @@ class TestAlchemyCacheStorage(unittest.TestCase):
             items = storage.dump_cache()
             self.assertEqual(len(items), 3)
             self.assertNotEqual(items[2].request_fingerprint, items[1].request_fingerprint)
+            storage.close_spider(None)
+
+            # Test store text if extract content is False
+            settings.set('SCRACHY_USE_CONTENT_EXTRACTION', False)
+            settings.set('SCRACHY_STORE_TEXT', True)
+            storage = AlchemyCacheStorage(settings)
+
+            storage.open_spider(None)
+            with self.assertLogs('scrachy.middleware.httpcache', level='WARNING') as log_ctx:
+                storage.open_spider(None)
+
+            self.assertTrue(
+                "SCRACHY_STORE_TEXT is True, but SCRACHY_USE_CONTENT_EXTRACTION is False"
+                in log_ctx.output[0]
+            )
+            storage.store_response(None, request4, response4)
+            items = storage.dump_cache()
+            item = items[-1]
+            self.assertEqual(item.response_body_text, None)
 
     # Simhash
     def test_tokenization_and_punctuation(self):
@@ -418,6 +440,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         request, response = make_response_from_file(filename, url)
 
         settings = make_settings(self.region_name)
+        settings.set('SCRACHY_USE_CONTENT_EXTRACTION', True)
         settings.set('SCRACHY_USE_SIMHASH', True)
 
         storage = AlchemyCacheStorage(settings)
@@ -429,6 +452,26 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         act_value = item.response_body_text_simhash
         exp_value = 3567515302636924889
         self.assertEqual(act_value, exp_value)
+        storage.close_spider(None)
+
+        # Test there's a warning if extract content is False
+        settings.set('SCRACHY_USE_CONTENT_EXTRACTION', False)
+        settings.set('SCRACHY_USE_SIMHASH', True)
+
+        storage = AlchemyCacheStorage(settings)
+        with self.assertLogs('scrachy.middleware.httpcache', level='WARNING') as log_ctx:
+            storage.open_spider(None)
+
+        storage.store_response(None, request, response)
+
+        self.assertTrue(
+            "SCRACHY_USE_SIMHASH is True, but SCRACHY_USE_CONTENT_EXTRACTION is False"
+            in log_ctx.output[0]
+        )
+
+        item = storage.dump_cache()[-1]
+
+        self.assertIsNone(item.response_body_text_simhash)
 
     def test_store_response_content_extraction(self):
         # If store response test works then the basic content extraction
@@ -485,6 +528,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         with tempfile.NamedTemporaryFile() as tf:
             # Add some items to the cache
             settings.set('SCRACHY_DATABASE', tf.name)
+            settings.set('SCRACHY_USE_CONTENT_EXTRACTION', True)
             settings.set('SCRACHY_STORE_TEXT', True)
             settings.set('SCRACHY_USE_SIMHASH', True)
 
@@ -631,6 +675,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         # Test the basic extractor
         settings = make_settings(
             self.region_name,
+            use_content_extraction=True,
             store_text=True,
             content_extraction_method='basic'
         )
@@ -653,6 +698,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         # Test the default extractor
         settings = make_settings(
             self.region_name,
+            use_content_extraction=True,
             store_text=True,
             content_extraction_method='boilerpipe_default'
         )
@@ -669,6 +715,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
 
         settings = make_settings(
             self.region_name,
+            use_content_extraction=True,
             store_text=True,
             content_extraction_method='boilerpipe_article'
         )
